@@ -2,7 +2,7 @@ package AI::Genetic::Pro;
 
 use vars qw($VERSION);
 
-$VERSION = 1.002;
+$VERSION = 1.003;
 #---------------
 
 use warnings;
@@ -366,8 +366,14 @@ sub as_array {
 	my ($self, $chromosome) = @_;
 	
 	if($self->type eq q/bitvector/){
-		return @$chromosome if wantarray;
-		return $chromosome;
+		# This could lead to internal error, bacause of underlaying Tie::Array::Packed
+		#return @$chromosome if wantarray;
+		#return $chromosome;
+		
+		my @chr = @$chromosome;
+		return @chr if wantarray;
+		return \@chr;
+		
 	}elsif($self->type eq q/rangevector/){
 		my $fix_range = $self->_fix_range;
 		my $c = -1;
@@ -592,7 +598,7 @@ sub evolve {
 	
 	if($self->strict){
 		$self->_strict( [ ] );
-		push @{$self->_strict}, clone($_) for @{$self->chromosomes};
+		push @{$self->_strict}, $_->clone for @{$self->chromosomes};
 	}
 }
 #=======================================================================
